第六感 (豆瓣)
Description: 第六感电影简介和剧情介绍,第六感影评、图片、预告片、影讯、论坛、在线购票
Keywords: 第六感,The Sixth Sense,第六感影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.108豆瓣电影Top250

# 第六感 The Sixth Sense (1999)

导演: M·奈特·沙马兰
编剧: M·奈特·沙马兰
主演: 布鲁斯·威利斯 / 海利·乔·奥斯蒙 / 托妮·科莱特 / 奥莉维亚·威廉姆斯 / 唐尼·沃尔伯格 / 特拉沃·摩根 / 彼得·安东尼·唐伯蒂斯 / 格伦·菲茨杰拉德 / 米莎·巴顿 / Lisa Summerour / 法尔德斯·巴姆 / 杰弗里·泽布尼斯
类型: 剧情 / 悬疑 / 惊悚
制片国家/地区: 美国
语言: 英语 / 拉丁语 / 西班牙语
上映日期: 1999-08-06(美国)
片长: 107分钟
又名: 鬼眼(港) / 灵异第六感(台)
IMDb: tt0167404
豆瓣评分
引用
8.9
528455人评价
5星
54.3%
4星
37.6%
3星
7.5%
2星
0.4%
1星
0.1%
好于 98% 悬疑片
好于 99% 惊悚片
想看 看过
评价:
推荐

## 第六感的剧情简介 · · · · · ·

麦克（布鲁斯·威利斯 饰）是著名儿童心理学家，却也有始终未能治愈的患者，甚至因此遭到枪击，这名少年随后也饮枪自毙。这给麦克带来很大心理阴影，一年后他找到另一个症状很像这名患者的男孩柯尔（海利·乔·奥斯蒙 饰），并耐心的做起了他的医生。柯尔并不容易接近，但麦克还是慢慢赢得 了他的信任，得知了柯尔的秘密。原来柯尔有着灵异的第六感，可以看到鬼魂。虽然这令人感到难以置信，但麦克在证实了事情的真相后还是帮助柯尔接受了这个事实。
可是就在问题即将得到解决的时候，麦克却在柯尔的引导下，发现了一个更令人震惊的秘密…… ©豆瓣

## 第六感的演职员 · · · · · · ( 全部 30 )

- M·奈特·沙马兰 导演
- 布鲁斯·威利斯 演员
- 海利·乔·奥斯蒙 演员
- 托妮·科莱特 演员
- 奥莉维亚·威廉姆斯 演员
- 唐尼·沃尔伯格 演员

## 第六感的视频和图片 · · · · · · ( 预告片1 | 视频评论1 · 添加 | 图片538 · 添加 )

## 第六感的获奖情况 · · · · · · ( 全部 )

- 第72届奥斯卡金像奖
- 最佳影片(提名)
- 凯瑟琳·肯尼迪 / 巴里·门德尔 / 弗兰克·马歇尔

- 第56届戛纳电影节
- DVD Design Award

- 第57届金球奖
- 电影类 最佳男配角(提名)
- 海利·乔·奥斯蒙

## 喜欢这部电影的人也喜欢 · · · · · ·

  恐怖游轮

  禁闭岛

  致命ID

  记忆碎片

  小岛惊魂

  万能钥匙

  闪灵

  沉默的羔羊

  蝴蝶效应

  穆赫兰道

我要写短评

## 第六感的短评 · · · · · · ( 全部 115923 条 )

热门 / 最新 / 好友

### 693 有用 Brasidas 看过 2009-10-06 22:20:57

一开始看以为是心理片，看了一半失望的发现是老套的鬼片，看到最后惊奇的发现原来是鬼心理片，晕~~

### 3491 有用 大头绿豆 看过 2005-09-12 20:17:22

还好我没知道结局就看了。

### 1793 有用 恶魔的步调 看过 2006-08-02 18:32:54

又是一部以结局见长的电影

### 184 有用 欢乐分裂 看过 2013-02-04 16:29:01

小孩的眼神真忧郁，打着恐怖片名头的温情片。

### 1931 有用 桃桃林林 看过 2010-01-09 20:23:17

反转王加催泪王

> 更多短评 115923条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 第六感的影评 · · · · · · ( 全部 1020 条 )

热门 / 最新 / 好友
白小小 2006-01-10 14:00:32

## 神啊，我自深渊向你呼喊

这篇影评可能有剧透

——“神啊，我自深渊向你呼喊” 在谈这部影片之前，必须先承认一下：我是一个足够落伍的人。在这部影片上映之时的2000年我还不知道DVD为何物，因此当我看到这部影片的时候，已经是在时过境迁的5年之后了……但是，它还是深深的感染并震撼了我。 很多人讲这是一部恐怖片或者惊... (展开)
3212 222 311回应 收起
普通人 2006-04-25 13:48:11

## 人与鬼魂的对话——《第六感》

好莱坞有一句笑言：不要与孩子或狗演电影。原因是他们会有意想不到的表现，要么毁了整部影片，使所有人放弃，要么表现得异常出色，抢去了主角的彩头。 这本是一部被我宿之高阁好几年的电影，因为我个人一度并不喜欢布鲁斯·威利斯这个演员。在我当初的印象中，他是一... (展开)
1292 169 159回应 收起
Beilia 2010-06-18 03:42:26

## 关于片中那个被毒死的小女孩的一点看法

这篇影评可能有剧透

首先，很多人假设那个母亲是继母，但是电影中并没有给予足够的证据来做出这样的假设，并没有交代说kyra的母亲死或者离婚的过程，并且在葬礼上还有一个看到他们的全家福，所以我认为还是假定是亲生母亲更合适一些。 这样就牵扯到为什么她会给自己的女儿下毒的问题，因为如果是亲... (展开)
1008 92 133回应 收起
十一月的雨 2007-02-03 12:56:50

## “我可以看见死人”――《第六感》

文：十一月的雨 1999年对三个人是值得纪念的年份，印度裔导演奈特·希亚马兰凭借自己的第二部作品《第六感》在好莱坞一鸣惊人，动作巨星布鲁斯·威利斯凭借《第六感》成功转型，天才童星海利·乔·奥斯蒙特凭借《第六感》中的精湛表演提名当年的奥斯卡最佳男配角。 于是我们的... (展开)
500 47 64回应 收起
Maverick 2015-01-28 14:45:49

## 《第六感》电影剧本

《第六感》电影剧本 好莱坞电影公司/望远镜娱乐公司1999年联合出品 编导：M·奈特·夏马南(M.Night Shyamalan) 主演：布鲁斯·威利斯（饰马尔科姆）、托尼·克莱特（琳·西尔）、乔·奥斯蒙德（科尔·希尔）、奥利维亚·威廉姆斯（安娜） 摄影：Tak Fujimoto 音乐：詹姆斯·牛... (展开)
291 11 16回应 收起
卡帕 2006-04-15 01:13:16

## The Sixth Sense

好莱坞的动作男星一旦温情起来，貌似还是很有点功力的。比如《保镖》里的Kevin Costner，《变脸》里的Nicolas Cage，还有这部&lt;The Sixth Sense&gt;里的Bruse Willis。 电影中他最后那个悲伤的转身，一切尽是虚无，回归一片平和的假象。 还有那个拥有鬼眼的小男孩。一口缠绵... (展开)
258 27 47回应 收起
凉风有心 2015-11-09 14:25:35

## 是救赎，亦是释放

这篇影评可能有剧透

第一次看这部电影已经是十多年前了，当时带给我的震撼却依然清晰。这绝对不是一部普通意义上的鬼片或者惊悚片，就像影评所说的：由开头的惊栗片格局一转再转，中段鬼怪出没而后段急转直下成为温情洋溢的家庭片，及致最后五分钟的高潮揭谜底戏，真令人意料不到。即便是看过多部... (展开)
177 8 5回应 收起
方醒儿 2008-05-31 16:17:01

## 孩子这样的美好生物

你会相信一个孩子么？ 即使他说得真实，从第一反应而言，浮于你脑中的会有几分相信？ Cole Sear说，你不相信我，你怎么帮助我。 他是一个孩子，他的眼神夹杂着泪水，如刀片般，亦很脆弱。 我极少有机会与孩子相处，因为我不是幼稚园教师或是如Dr. Malcolm Crowe般的儿童心理辅... (展开)
109 9 22回应 收起
追风筝的人 2008-03-11 19:34:35

## 鬼臆，任是看透也枉然

好莱坞每年都会出几部佳片，当然咯，烂片一贯会更多。1999年，称得上经典之作的电影群尤其庞大，敢情导演也喜欢扎堆。粗粗算一下，有对后来的剧情片影响深刻的《美国丽人》《绿里奇迹》《美国派》，商业片里出了《木乃伊》《黑客帝国》《星战前传》，我个人喜欢的《八毫米》《... (展开)
131 11 10回应 收起

> 更多影评 1020篇

添加新讨论

## 讨论区 · · · · · ·

我有一个疑问？小男孩是医生老婆自己生的？还是领... | 来自酷爱吃奶 | 78 回应 | 2022-11-12 01:36:51
我很疑惑为什么小男孩明明害怕和鬼魂交流却选择和... | 来自sherksice | 12 回应 | 2022-11-09 14:20:38
有N个疑惑，你帮我解答几个？ | 来自popo | 17 回应 | 2022-11-09 14:17:04
（剧透预警）我认为男孩Cole并不知道男主医生的真... | 来自V | 26 回应 | 2022-11-09 14:00:18
看的时候一直以为开头在浴室开枪的男人是Cole长大... | 来自Chloé | 2 回应 | 2022-11-07 14:41:41

> 去这部影片的讨论区（全部345条）

## 关于《第六感》的问题 · · · · · · ( 全部56个 )

- 这是bug吗？ 20人回答
- 为什么开头那个裸男可以把布鲁斯杀死啊？ 13人回答

> 全部56个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【意外结局】 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 7分以上的恐怖/惊悚电影 (冬至)
- {北美电影票房总排行} (荔枝超人)

## 谁在看这部电影 · · · · · ·

- 呆b旺崽儿
  1分钟前 想看
- 大马哈鱼 卵
  5分钟前 想看
- 小屁孩儿
  6分钟前 看过

713805人看过 / 313279人想看

订阅第六感的评论:
feed: rss 2.0